@@ -24,7 +24,10 @@
 #include "sprite.h"
 
 #include "killbots_debug.h"
-#include <KRandom>
+
+#include <QRandomGenerator>
+
+#include <array>
 
 uint qHash(const QPoint &point)
 {
@@ -111,7 +114,7 @@ void Killbots::Engine::startNewGame()
 
     // Don't show the new game message on first start.
     if (m_round != 0) {
-        emit showNewGameMessage();
+        Q_EMIT showNewGameMessage();
     }
 
     m_heroIsDead = false;
@@ -124,10 +127,10 @@ void Killbots::Engine::startNewGame()
     m_fastbotCount = m_rules->fastEnemiesAtGameStart();
     m_junkheapCount = m_rules->junkheapsAtGameStart();
 
-    emit teleportAllowed(true);
-    emit waitOutRoundAllowed(true);
-    emit teleportSafelyAllowed(canSafeTeleport());
-    emit vaporizerAllowed(canUseVaporizer());
+    Q_EMIT teleportAllowed(true);
+    Q_EMIT waitOutRoundAllowed(true);
+    Q_EMIT teleportSafelyAllowed(canSafeTeleport());
+    Q_EMIT vaporizerAllowed(canUseVaporizer());
 
     // Code used to generate theme previews
     //newRound( "  r\nhjf", false );
@@ -200,10 +203,10 @@ void Killbots::Engine::startNewRound(bool incrementRound, const QString &layout)
         }
     }
 
-    emit roundChanged(m_round);
-    emit scoreChanged(m_score);
-    emit enemyCountChanged(m_bots.size());
-    emit energyChanged(m_energy);
+    Q_EMIT roundChanged(m_round);
+    Q_EMIT scoreChanged(m_score);
+    Q_EMIT enemyCountChanged(m_bots.size());
+    Q_EMIT energyChanged(m_energy);
 
     refreshSpriteMap();
 }
@@ -248,7 +251,8 @@ bool Killbots::Engine::teleportHeroSafely()
     refreshSpriteMap();
 
     // Choose a random cell...
-    const QPoint startPoint = QPoint(KRandom::random() % m_rules->columns(), KRandom::random() % m_rules->rows());
+    const QPoint startPoint = QPoint(QRandomGenerator::global()->bounded(m_rules->columns()),
+                                     QRandomGenerator::global()->bounded(m_rules->rows()));
     QPoint point = startPoint;
 
     // ...and step through all the cells on the board looking for a safe cell.
@@ -296,7 +300,7 @@ bool Killbots::Engine::useVaporizer()
 
     if (!neighbors.isEmpty()) {
         m_coordinator->beginNewAnimationStage();
-        foreach (Sprite *sprite, neighbors) {
+        for (Sprite *sprite : qAsConst(neighbors)) {
             destroySprite(sprite);
         }
         updateEnergy(-m_rules->costOfVaporizer());
@@ -318,7 +322,7 @@ void Killbots::Engine::moveRobots(bool justFastbots)
 
     if (justFastbots) {
         refreshSpriteMap();
-        foreach (Sprite *bot, m_bots) {
+        for (Sprite *bot : qAsConst(m_bots)) {
             if (bot->spriteType() == Fastbot) {
                 const QPoint offset(sign(m_hero->gridPos().x() - bot->gridPos().x()), sign(m_hero->gridPos().y() - bot->gridPos().y()));
                 const QPoint target = bot->gridPos() + offset;
@@ -328,7 +332,7 @@ void Killbots::Engine::moveRobots(bool justFastbots)
             }
         }
     } else {
-        foreach (Sprite *bot, m_bots) {
+        for (Sprite *bot : qAsConst(m_bots)) {
             const QPoint offset(sign(m_hero->gridPos().x() - bot->gridPos().x()), sign(m_hero->gridPos().y() - bot->gridPos().y()));
             m_coordinator->slideSprite(bot, bot->gridPos() + offset);
         }
@@ -346,7 +350,8 @@ void Killbots::Engine::assessDamage()
     }
 
     // Check junkheaps for dead robots
-    foreach (Sprite *junkheap, m_junkheaps) {
+    const auto junkheaps = m_junkheaps;
+    for (Sprite *junkheap : junkheaps) {
         destroyAllCollidingBots(junkheap, !m_heroIsDead);
     }
 
@@ -364,14 +369,14 @@ void Killbots::Engine::assessDamage()
 
     if (isRoundComplete()) {
         m_coordinator->beginNewAnimationStage();
-        emit showRoundCompleteMessage();
+        Q_EMIT showRoundCompleteMessage();
     }
 }
 
 void Killbots::Engine::resetBotCounts()
 {
     m_coordinator->beginNewAnimationStage();
-    emit showBoardFullMessage();
+    Q_EMIT showBoardFullMessage();
 
     m_maxEnergy = m_rules->maxEnergyAtGameStart();
     m_robotCount = m_rules->enemiesAtGameStart();
@@ -384,12 +389,12 @@ void Killbots::Engine::resetBotCounts()
 
 void Killbots::Engine::endGame()
 {
-    emit showGameOverMessage();
-    emit teleportAllowed(false);
-    emit waitOutRoundAllowed(false);
-    emit teleportSafelyAllowed(false);
-    emit vaporizerAllowed(false);
-    emit gameOver(m_score, m_round);
+    Q_EMIT showGameOverMessage();
+    Q_EMIT teleportAllowed(false);
+    Q_EMIT waitOutRoundAllowed(false);
+    Q_EMIT teleportSafelyAllowed(false);
+    Q_EMIT vaporizerAllowed(false);
+    Q_EMIT gameOver(m_score, m_round);
 }
 
 // The hero action functions and the assessDamage functions must know the
@@ -398,10 +403,10 @@ void Killbots::Engine::endGame()
 void Killbots::Engine::refreshSpriteMap()
 {
     m_spriteMap.clear();
-    foreach (Sprite *bot, m_bots) {
+    for (Sprite *bot : qAsConst(m_bots)) {
         m_spriteMap.insert(bot->gridPos(), bot);
     }
-    foreach (Sprite *junkheap, m_junkheaps) {
+    for (Sprite *junkheap : qAsConst(m_junkheaps)) {
         m_spriteMap.insert(junkheap->gridPos(), junkheap);
     }
 }
@@ -449,7 +454,8 @@ QPoint Killbots::Engine::randomEmptyCell() const
 {
     QPoint point;
     do {
-        point = QPoint(KRandom::random() % m_rules->columns(), KRandom::random() % m_rules->rows());
+        point = QPoint(QRandomGenerator::global()->bounded(m_rules->columns()),
+                       QRandomGenerator::global()->bounded(m_rules->rows()));
     } while (spriteTypeAt(point) != NoSprite || point == m_hero->gridPos());
     return point;
 }
@@ -640,19 +646,20 @@ bool Killbots::Engine::moveIsSafe(const QPoint &cell, HeroAction direction) cons
             // If we're examining an vertical or horizontal neighbour, things are more complicated...
             else {
                 // Assemble a list of the cells behind the neighbour.
-                QList<QPoint> cellsBehindNeighbor;
-                cellsBehindNeighbor << neighborsNeighbor;
+                const std::array<QPoint, 3> cellsBehindNeighbor {
+		    neighborsNeighbor,
                 // Add neighboursNeighbour's anticlockwise neighbour.
                 // ( i + 2 ) % 8 is the direction a quarter turn anticlockwise from i.
-                cellsBehindNeighbor << neighborsNeighbor + offsetFromDirection((i + 2) % 8);
+		    neighborsNeighbor + offsetFromDirection((i + 2) % 8),
                 // Add neighboursNeighbour's clockwise neighbour.
                 // ( i + 6 ) % 8 is the direction a quarter turn clockwise from i.
-                cellsBehindNeighbor << neighborsNeighbor + offsetFromDirection((i + 6) % 8);
+		    neighborsNeighbor + offsetFromDirection((i + 6) % 8),
+		};
 
                 // Then we just count the number of fastbots and robots in the list of cells.
                 int fastbotsFound = 0;
                 int robotsFound = 0;
-                foreach (const QPoint &cell, cellsBehindNeighbor) {
+                for (const QPoint &cell : cellsBehindNeighbor) {
                     if (spriteTypeAt(cell) == Fastbot) {
                         ++fastbotsFound;
                     } else if (spriteTypeAt(cell) == Robot) {
@@ -716,14 +723,18 @@ void Killbots::Engine::cleanUpRound()
     }
     m_hero = nullptr;
 
-    foreach (Sprite *bot, m_bots) {
+    const auto bots = m_bots;
+    for (Sprite *bot : bots) {
         destroySprite(bot, false);
     }
+    Q_ASSERT(m_bots.isEmpty());
     m_bots.clear();
 
-    foreach (Sprite *junkheap, m_junkheaps) {
+    const auto junkheaps = m_junkheaps;
+    for (Sprite *junkheap : junkheaps) {
         destroySprite(junkheap);
     }
+    Q_ASSERT(m_junkheaps.isEmpty());
     m_junkheaps.clear();
 
     m_spriteMap.clear();
@@ -747,7 +758,7 @@ void Killbots::Engine::destroySprite(Sprite *sprite, bool calculatePoints)
             }
         }
         m_bots.removeOne(sprite);
-        emit enemyCountChanged(m_bots.size());
+        Q_EMIT enemyCountChanged(m_bots.size());
     } else if (type == Junkheap) {
         m_junkheaps.removeOne(sprite);
     }
@@ -759,7 +770,8 @@ bool Killbots::Engine::destroyAllCollidingBots(const Sprite *sprite, bool calcul
 {
     bool result = false;
 
-    foreach (Sprite *robot, m_spriteMap.values(sprite->gridPos())) {
+    const auto robotsAtPos = m_spriteMap.values(sprite->gridPos());
+    for (Sprite *robot : robotsAtPos) {
         if (robot != sprite && (robot->spriteType() == Robot || robot->spriteType() == Fastbot)) {
             destroySprite(robot, calculatePoints);
             result = true;
@@ -773,7 +785,7 @@ void Killbots::Engine::updateScore(int changeInScore)
 {
     if (changeInScore != 0) {
         m_score = m_score + changeInScore;
-        emit scoreChanged(m_score);
+        Q_EMIT scoreChanged(m_score);
     }
 }
 
@@ -789,9 +801,9 @@ void Killbots::Engine::updateEnergy(int changeInEnergy)
             m_energy = m_energy + changeInEnergy;
         }
 
-        emit energyChanged(m_energy);
-        emit teleportSafelyAllowed(canSafeTeleport());
-        emit vaporizerAllowed(canUseVaporizer());
+        Q_EMIT energyChanged(m_energy);
+        Q_EMIT teleportSafelyAllowed(canSafeTeleport());
+        Q_EMIT vaporizerAllowed(canUseVaporizer());
     }
 }
 
