@@ -21,7 +21,7 @@
 #include "killbots_version.h"
 
 #include <KLocalizedString>
-#include <kdelibs4configmigrator.h>
+#include <Kdelibs4ConfigMigrator>
 #include <QApplication>
 #include <KAboutData>
 #include <KCrash>
@@ -30,7 +30,10 @@
 
 int main(int argc, char **argv)
 {
-    QApplication app(argc, argv);
+    // Fixes blurry icons with fractional scaling
+    QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+
+	QApplication app(argc, argv);
 
     Kdelibs4ConfigMigrator migrate(QStringLiteral("killbots"));
     migrate.setConfigFiles(QStringList() << QStringLiteral("killbotsrc"));
