@@ -100,19 +100,19 @@ void Killbots::MainWindow::configurePreferences()
 
         // Creating setting pages and adding them to the dialog
         configDialog->addPage(new OptionsPage(this),
-                              i18n("General"),
+                              i18nc("@title", "General"),
                               QStringLiteral("configure"),
-                              i18n("Configure general settings")
+                              i18nc("@info", "Configure general settings")
                              );
         configDialog->addPage(new RulesetSelector(this),
-                              i18n("Game Type"),
+                              i18nc("@title", "Game Type"),
                               QStringLiteral("games-config-custom"),
-                              i18n("Select a game type")
+                              i18nc("@info", "Select a game type")
                              );
         configDialog->addPage(new KgThemeSelector(Renderer::self()->themeProvider()),
-                              i18n("Appearance"),
+                              i18nc("@title", "Appearance"),
                               QStringLiteral("games-config-theme"),
-                              i18n("Select a graphical theme")
+                              i18nc("@info", "Select a graphical theme")
                              );
 
         configDialog->setMaximumSize(800, 600);
@@ -147,9 +147,9 @@ void Killbots::MainWindow::onConfigDialogClosed()
         if (!m_engine->gameHasStarted()
                 || KMessageBox::questionYesNo(this,
                                               i18n("A new game type has been selected, but there is already a game in progress."),
-                                              i18n("Game Type Changed"),
-                                              KGuiItem(i18n("Continue Current Game")),
-                                              KGuiItem(i18n("Start a New Game"))
+                                              i18nc("@title:window", "Game Type Changed"),
+                                              KGuiItem(i18nc("@action:button", "Continue Current Game")),
+                                              KGuiItem(i18nc("@action:button", "Start a New Game"))
                                              ) == KMessageBox::No
            ) {
             m_coordinator->requestNewGame();
@@ -162,17 +162,17 @@ void Killbots::MainWindow::onConfigDialogClosed()
 void Killbots::MainWindow::createScoreDialog()
 {
     m_scoreDialog = new KScoreDialog(KScoreDialog::Name, this);
-    m_scoreDialog->addField(KScoreDialog::Level, i18n("Round"), QStringLiteral("round"));
+    m_scoreDialog->addField(KScoreDialog::Level, i18nc("@title:column round of the game", "Round"), QStringLiteral("round"));
     m_scoreDialog->setModal(false);
     QStringList fileList;
     const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("killbots/ruleset"), QStandardPaths::LocateDirectory);
-    Q_FOREACH (const QString &dir, dirs) {
+    for (const QString &dir : dirs) {
         const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.desktop"));
-        Q_FOREACH (const QString &file, fileNames) {
+        for (const QString &file : fileNames) {
             fileList.append(dir + QLatin1Char('/') + file);
         }
     }
-    foreach (const QString &fileName, fileList) {
+    for (const QString &fileName : qAsConst(fileList)) {
         const Ruleset *ruleset = Ruleset::load(fileName);
         if (ruleset) {
             m_scoreDialog->addLocalizedConfigGroupName(qMakePair(ruleset->scoreGroupKey(), ruleset->name()));
@@ -246,94 +246,94 @@ void Killbots::MainWindow::setupActions()
 
     createMappedAction(TeleportSafely,
                        QStringLiteral("teleport_safely"),
-                       i18n("Teleport Safely"),
+                       i18nc("@action", "Teleport Safely"),
                        i18nc("Shortcut for teleport safely. See https://quickgit.kde.org/?p=killbots.git&a=blob&f=README.translators&o=plain", "T"),
                        Qt::Key_Plus,
-                       i18n("Teleport to a safe location"),
+                       i18nc("@info:tooltip", "Teleport to a safe location"),
                        QStringLiteral("games-solve")
                       );
     createMappedAction(Teleport,
                        QStringLiteral("teleport"),
-                       i18n("Teleport"),
+                       i18nc("@action", "Teleport"),
                        i18nc("Shortcut for teleport. See https://quickgit.kde.org/?p=killbots.git&a=blob&f=README.translators&o=plain", "R"),
                        Qt::Key_Minus,
-                       i18n("Teleport to a random location"),
+                       i18nc("@info:tooltip", "Teleport to a random location"),
                        QStringLiteral("roll")
                       );
     createMappedAction(TeleportSafelyIfPossible,
                        QStringLiteral("teleport_sip"),
-                       i18n("Teleport, Safely If Possible"),
+                       i18nc("@action", "Teleport (Safely If Possible)"),
                        i18nc("Shortcut for teleport safely if possible. See https://quickgit.kde.org/?p=killbots.git&a=blob&f=README.translators&o=plain", "Space"),
                        Qt::Key_0,
-                       i18n("Teleport safely if that action is enabled, otherwise teleport randomly")
+                       i18nc("@info:tooltip", "Teleport safely if that action is enabled, otherwise teleport randomly")
                       );
     createMappedAction(Vaporizer,
                        QStringLiteral("vaporizer"),
-                       i18n("Vaporizer"),
+                       i18nc("@action", "Vaporizer"),
                        i18nc("Shortcut for vaporizer. See https://quickgit.kde.org/?p=killbots.git&a=blob&f=README.translators&o=plain", "F"),
                        Qt::Key_Period,
-                       i18n("Destroy all enemies in neighboring cells"),
+                       i18nc("@info:tooltip", "Destroy all enemies in neighboring cells"),
                        QStringLiteral("edit-bomb")
                       );
     createMappedAction(WaitOutRound,
                        QStringLiteral("wait_out_round"),
-                       i18n("Wait Out Round"),
+                       i18nc("@action", "Wait Out Round"),
                        i18nc("Shortcut for wait out round. See https://quickgit.kde.org/?p=killbots.git&a=blob&f=README.translators&o=plain", "V"),
                        Qt::Key_Asterisk,
-                       i18n("Risk remaining in place until the end of the round for bonuses"),
+                       i18nc("@info:tooltip", "Risk remaining in place until the end of the round for bonuses"),
                        QStringLiteral("process-stop")
                       );
     createMappedAction(UpLeft,
                        QStringLiteral("move_up_left"),
-                       i18n("Move Up and Left"),
+                       i18nc("@action", "Move Up and Left"),
                        i18nc("Shortcut for move up and left. https://quickgit.kde.org/?p=killbots.git&a=blob&f=README.translators&o=plain", "Q"),
                        Qt::Key_7
                       );
     createMappedAction(Up,
                        QStringLiteral("move_up"),
-                       i18n("Move Up"),
+                       i18nc("@action", "Move Up"),
                        i18nc("Shortcut for move up. See https://quickgit.kde.org/?p=killbots.git&a=blob&f=README.translators&o=plain", "W"),
                        Qt::Key_8
                       );
     createMappedAction(UpRight,
                        QStringLiteral("move_up_right"),
-                       i18n("Move Up and Right"),
+                       i18nc("@action", "Move Up and Right"),
                        i18nc("Shortcut for move up and right. https://quickgit.kde.org/?p=killbots.git&a=blob&f=README.translators&o=plain", "E"),
                        Qt::Key_9
                       );
     createMappedAction(Left,
                        QStringLiteral("move_left"),
-                       i18n("Move Left"),
+                       i18nc("@action", "Move Left"),
                        i18nc("Shortcut for move left. See https://quickgit.kde.org/?p=killbots.git&a=blob&f=README.translators&o=plain", "A"),
                        Qt::Key_4
                       );
     createMappedAction(Hold,
                        QStringLiteral("stand_still"),
-                       i18n("Stand Still"),
+                       i18nc("@action", "Stand Still"),
                        i18nc("Shortcut for stand still. See https://quickgit.kde.org/?p=killbots.git&a=blob&f=README.translators&o=plain", "S"),
                        Qt::Key_5
                       );
     createMappedAction(Right,
                        QStringLiteral("move_right"),
-                       i18n("Move Right"),
+                       i18nc("@action", "Move Right"),
                        i18nc("Shortcut for move right. See https://quickgit.kde.org/?p=killbots.git&a=blob&f=README.translators&o=plain", "D"),
                        Qt::Key_6
                       );
     createMappedAction(DownLeft,
                        QStringLiteral("move_down_left"),
-                       i18n("Move Down and Left"),
+                       i18nc("@action", "Move Down and Left"),
                        i18nc("Shortcut for move down and left. See https://quickgit.kde.org/?p=killbots.git&a=blob&f=README.translators&o=plain", "Z"),
                        Qt::Key_1
                       );
     createMappedAction(Down,
                        QStringLiteral("move_down"),
-                       i18n("Move Down"),
+                       i18nc("@action", "Move Down"),
                        i18nc("Shortcut for move down. See https://quickgit.kde.org/?p=killbots.git&a=blob&f=README.translators&o=plain", "X"),
                        Qt::Key_2
                       );
     createMappedAction(DownRight,
                        QStringLiteral("move_down_right"),
-                       i18n("Move Down and Right"),
+                       i18nc("@action", "Move Down and Right"),
                        i18nc("Shortcut for move down and right. https://quickgit.kde.org/?p=killbots.git&a=blob&f=README.translators&o=plain", "C"),
                        Qt::Key_3
                       );
